@@ -172,7 +172,22 @@ Arnolfini.getPrevEvent = function ()
 }
 
 $(document).ready(function() {
-	//Arnolfini.events();
+	Arnolfini.events();
 	Arnolfini.archiveShowButtons();
+	if ($(".columns").length > 0)
+	{
+		 var currentLetter= "";
+		 $('.separateByLetters').find('h2.summary a').each(function ()
+								{
+									var name = $(this).text();
+									firstLetter = name[0].toUpperCase();
+									if (firstLetter != currentLetter)
+									{
+										currentLetter = firstLetter;
+										$(this).parent().prepend($('<a class="letter dontend" name="'+firstLetter+'">'+firstLetter+'</a>'));
+									}
+								});
+		 $('.columns').columnize({ width:300 });
+	}
 });
 
