@@ -8,6 +8,7 @@ from Products.CMFPlone.PloneBatch import Batch
 from datetime import date
 from DateTime import DateTime
 from plone.app.querystring import queryparser
+from collective.media.interfaces import ICanContainMedia
 import re
 
 
@@ -29,9 +30,21 @@ class CommonBrowserView(BrowserView):
         return structure
     
     def getLeadMediaTag(self, item, scale="large"):
+        #TODO: Check if its a brains item, else adapt ICanContainMedia first. see below on containsMedia
         lead = item.leadMedia
         if lead is not None:
             return '<img src="%(url)s" alt="%(title)s" title="%(title)s" />'%{'url': "%s/image_%s"%(lead, scale), 'title':item.Title}
+        
+    def containsMedia(self, item):
+        if hasattr(item, 'hasMedia'):
+            return item.hasMedia
+        else:
+            catalog = getToolByName(self.context, 'portal_catalog')
+            brains = catalog.queryCatalog({"UID": item.UID()})
+            if len(brains) != 0:
+                return brains[0].hasMedia
+            else:
+                return False
     
     def trimText(self, text, limit, strip=False):
         if strip:
@@ -259,7 +272,16 @@ class FolderListing(CommonBrowserView):
             
         return results
     
-class SearchView(Search):
+    def sort_by_alpha(self, results, field):
+        """
+        Sorts results by field in alphabetic order
+        """
+        res_list = list(results)
+        final_res = sorted(res_list, key=lambda x: getattr(x, field, False))
+        
+        return Batch(final_res, results.size, start=results.start)
+    
+class SearchView(CommonBrowserView, Search):
     """
     Adding to Search view
     """
